==> 0.1.47.tar.gz: lib/utils/styles.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:oowoo_core/oowoo_core.dart';

//Colors
Color get loginTextGrey => hexColor('#7A869A');
Color get loginTextHint => hexColor('#A9BBD9');
Color get loginTextBlack => hexColor('#1C222C');
Color get loginTextDark => hexColor('#EDF5FA');
Color get loginTextGlass => hexColor('#2B303C');
Color get loginTextPlaceholderGrey => hexColor('#D9DCE2');

Color get bottomSheetGrip => hexColor('#F2F4F7');
Color get bottomSheetBg => hexColor('#F2F4F7');

Color get textColor => appColors?.text ?? hexColor('#4C82F6'); 
Color get redCircle => hexColor('#ED2E7F');
Color get elementColor => hexColor('#F2F4F7');

//TextStyles
TextStyle get robotoBold => GoogleFonts.roboto(textStyle: _bold);
TextStyle get robotoBoldBlack => GoogleFonts.roboto(textStyle: _boldBlack);
TextStyle get robotoMedium => GoogleFonts.roboto(textStyle: _medium);
TextStyle get robotoRegular => GoogleFonts.roboto(textStyle: _regular);
TextStyle get robotoLight => GoogleFonts.roboto(textStyle: _light);

TextStyle get rubikBold => GoogleFonts.rubik(textStyle: _bold);
TextStyle get rubikBoldBlack => GoogleFonts.rubik(textStyle: _boldBlack);
TextStyle get rubikMedium => GoogleFonts.rubik(textStyle: _medium);
TextStyle get rubikRegular => GoogleFonts.rubik(textStyle: _regular);
TextStyle get rubikLight => GoogleFonts.rubik(textStyle: _light);

TextStyle get latoBold => GoogleFonts.lato(textStyle: _bold);
TextStyle get latoBoldBlack => GoogleFonts.lato(textStyle: _boldBlack);
TextStyle get latoMedium => GoogleFonts.lato(textStyle: _medium);
TextStyle get latoRegular => GoogleFonts.lato(textStyle: _regular);
TextStyle get latoLight => GoogleFonts.lato(textStyle: _light);

TextStyle get openSansBold => GoogleFonts.openSans(textStyle: _bold);
TextStyle get openSansBoldBlack => GoogleFonts.openSans(textStyle: _boldBlack);
TextStyle get openSansMedium => GoogleFonts.openSans(textStyle: _medium);
TextStyle get openSansRegular => GoogleFonts.openSans(textStyle: _regular);
TextStyle get openSansLight => GoogleFonts.openSans(textStyle: _light);

TextStyle get assistantBold => GoogleFonts.assistant(textStyle: _bold);
TextStyle get assistantBoldBlack =>
    GoogleFonts.assistant(textStyle: _boldBlack);
TextStyle get assistantMedium => GoogleFonts.assistant(textStyle: _medium);
TextStyle get assistantRegular => GoogleFonts.assistant(textStyle: _regular);
TextStyle get assistantLight => GoogleFonts.assistant(textStyle: _light);

TextStyle get textStyleError => robotoMedium.copyWith(color: Colors.red);
TextStyle get textStyleSmall => robotoMedium;
TextStyle get loginHintInput =>
    robotoMedium.copyWith(color: loginTextHint, fontSize: 13.0);

//Styles
BorderRadius get borderButton => BorderRadius.circular((Get.context == null
        ? null
        : OOWOOTheme.of(Get.context!).loginBorderRadius) ??
    4);

TextStyle get _bold => TextStyle(
    height: 1.15, color: textColor, fontWeight: FontWeight.bold, fontSize: 14);
TextStyle get _boldBlack => TextStyle(
    height: 1.15, color: textColor, fontWeight: FontWeight.w900, fontSize: 14);
TextStyle get _medium => TextStyle(
    height: 1.15, color: textColor, fontWeight: FontWeight.w500, fontSize: 14);
TextStyle get _regular => TextStyle(
    height: 1.15, color: textColor, fontWeight: FontWeight.w400, fontSize: 14);
TextStyle get _light => TextStyle(
    height: 1.15, color: textColor, fontWeight: FontWeight.w300, fontSize: 14);

==> 0.2.9.tar.gz: lib/utils/styles.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:oowoo_core/oowoo_core.dart';

//Colors
Color get loginTextGrey => hexColor('#7A869A');
Color get loginTextHint => hexColor('#A9BBD9');
Color get loginTextBlack => hexColor('#1C222C');
Color get loginTextDark => hexColor('#EDF5FA');
Color get loginTextGlass => hexColor('#2B303C');
Color get loginTextPlaceholderGrey => hexColor('#D9DCE2');

Color get bottomSheetGrip => hexColor('#F2F4F7');
Color get bottomSheetBg => hexColor('#F2F4F7');

Color get textColor => appColors?.text ?? hexColor('#4C82F6');
Color get redCircle => hexColor('#ED2E7F');
Color get elementColor => hexColor('#F2F4F7');

//TextStyles
TextStyle get robotoBold => GoogleFonts.roboto(textStyle: _bold);
TextStyle get robotoBoldBlack => GoogleFonts.roboto(textStyle: _boldBlack);
TextStyle get robotoMedium => GoogleFonts.roboto(textStyle: _medium);
TextStyle get robotoRegular => GoogleFonts.roboto(textStyle: _regular);
TextStyle get robotoLight => GoogleFonts.roboto(textStyle: _light);

TextStyle get rubikBold => GoogleFonts.rubik(textStyle: _bold);
TextStyle get rubikBoldBlack => GoogleFonts.rubik(textStyle: _boldBlack);
TextStyle get rubikMedium => GoogleFonts.rubik(textStyle: _medium);
TextStyle get rubikRegular => GoogleFonts.rubik(textStyle: _regular);
TextStyle get rubikLight => GoogleFonts.rubik(textStyle: _light);

TextStyle get latoBold => GoogleFonts.lato(textStyle: _bold);
TextStyle get latoBoldBlack => GoogleFonts.lato(textStyle: _boldBlack);
TextStyle get latoMedium => GoogleFonts.lato(textStyle: _medium);
TextStyle get latoRegular => GoogleFonts.lato(textStyle: _regular);
TextStyle get latoLight => GoogleFonts.lato(textStyle: _light);

TextStyle get openSansBold => GoogleFonts.openSans(textStyle: _bold);
TextStyle get openSansBoldBlack => GoogleFonts.openSans(textStyle: _boldBlack);
TextStyle get openSansMedium => GoogleFonts.openSans(textStyle: _medium);
TextStyle get openSansRegular => GoogleFonts.openSans(textStyle: _regular);
TextStyle get openSansLight => GoogleFonts.openSans(textStyle: _light);

TextStyle get assistantBold => GoogleFonts.assistant(textStyle: _bold);
TextStyle get assistantBoldBlack =>
    GoogleFonts.assistant(textStyle: _boldBlack);
TextStyle get assistantMedium => GoogleFonts.assistant(textStyle: _medium);
TextStyle get assistantRegular => GoogleFonts.assistant(textStyle: _regular);
TextStyle get assistantLight => GoogleFonts.assistant(textStyle: _light);

TextStyle get textStyleError => robotoMedium.copyWith(color: Colors.red);
TextStyle get textStyleSmall => robotoMedium;
TextStyle get loginHintInput =>
    robotoMedium.copyWith(color: loginTextHint, fontSize: 13.0);

//Styles
BorderRadius get borderButton => BorderRadius.circular((Get.context == null
        ? null
        : OOWOOTheme.of(Get.context!).authMobileOptions?.borderRadius) ??
    4);

TextStyle get _bold => TextStyle(
    height: 1.15, color: textColor, fontWeight: FontWeight.bold, fontSize: 14);
TextStyle get _boldBlack => TextStyle(
    height: 1.15, color: textColor, fontWeight: FontWeight.w900, fontSize: 14);
TextStyle get _medium => TextStyle(
    height: 1.15, color: textColor, fontWeight: FontWeight.w500, fontSize: 14);
TextStyle get _regular => TextStyle(
    height: 1.15, color: textColor, fontWeight: FontWeight.w400, fontSize: 14);
TextStyle get _light => TextStyle(
    height: 1.15, color: textColor, fontWeight: FontWeight.w300, fontSize: 14);
